package com.zhentao.util;

import redis.clients.jedis.Jedis;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

public class OrderNumberGenerator {

    private static final String REDIS_KEY = "order_number";
    private static final String REDIS_HOST = "localhost";
    private static final int REDIS_PORT = 6379;
    private static final DateTimeFormatter DATE_TIME_FORMATTER = DateTimeFormatter.ofPattern("yyyyMMddHHmmss");

    /**
     * 生成格式化订单号
     * @return 格式化订单号
     */
    public static synchronized String generateOrderNumber() {
        // 连接Redis
        try (Jedis jedis = new Jedis(REDIS_HOST, REDIS_PORT)) {
            // 使用Redis的原子操作生成订单号
            Long nextOrderNumber = jedis.incr(REDIS_KEY);
            // 格式化订单号，例如：ORDER2023051512340001
            String orderNumber = String.format("ORDER%s%07d",
                    DATE_TIME_FORMATTER.format(LocalDateTime.now()),
                    nextOrderNumber);
            return orderNumber;
        }
    }

    public static void main(String[] args) {
        // 生成并打印订单号
        String orderNumber = generateOrderNumber();
        System.out.println("Generated Order Number: " + orderNumber);
    }
}
